Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Server ¶
func NewServer ¶
NewServer returns a Server instance with a default SSH server with the provided Middleware. A new SSH key pair of type ed25519 will be created if one does not exist. By default this server will accept all incoming connections, password and public key. Incase of an error an error is returned gracefuly for handling
Click to show internal directories.
Click to hide internal directories.